==> ReleaseV1.1.0.tar.gz: winginterfacelibrary/src/Interface/IDeviceService.cs <==
﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request.Device;
using WingInterfaceLibrary.DTO.Device;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Dictionary;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.DTO.DiagnosisModule;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 设备信息服务接口
    /// </summary>
    /// <value>设备信息接口</value>
    /// <example>客户端API</example>
    [System.ComponentModel.Description("DeviceService")]
    public interface IDeviceService
    {
        /// <summary>
        /// 设备心跳
        /// </summary>
        /// <param name="request">设备心跳请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> HeartRateAsync(TokenRequest request);

        Task<DeviceInfoDTO> CreateDeviceInfoAsync(CreateDeviceRequest request);

        /// <summary>
        /// 根据设备code获取设备信息
        /// </summary>
        /// <param name="request">设备code请求实体</param>
        /// <returns>返回查询到的设备对象信息</returns>
        /// <errorCodes>DeviceCodeEmpty,NoExistDevice</errorCodes>
        Task<DeviceExtendInfoDTO> GetDeviceInfoAsync(GetDeviceRequest request);

        /// <summary>
        /// 根据设备动态唯一码获取设备信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ShortCodeEmpty,NoExistDevice</errorCodes>
        Task<DeviceExtendInfoDTO> GetDeviceByShortCodeAsync(GetDeviceByShortCodeRequest request);

        Task<PageCollection<DeviceInfoDTO>> GetDeviceInfoPageAsync(PageFilterRequest request);

        /// <summary>
        /// 绑定设备
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserNotExistError,DeviceNotExist,HasAddedDevice</errorCodes>
        Task<bool> BindDeviceAsync(BindDeviceRequest request);

        /// <summary>
        /// 修改设备信息
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceNotExist,DeviceNameEmpty</errorCodes>
        Task<bool> ModifyDeviceAsync(ModifyDeviceRequest request);

        /// <summary>
        /// 创建设备类型、设备型号字典项
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>字典编码</returns>
        /// <value>DictionaryDO_2022030202525405wUxJ</value>
        Task<string> CreateDictionaryItemAsync(CreateDictionaryItemRequest request);

        /// <summary>
        /// 查找设备型号所有字典项
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>设备型号列表</returns>
        Task<List<DictionaryDTO>> FindDeviceModelItemsAsync(FindDeviceModelItemsRequest request);

        /// <summary>
        /// 查找设备类型所有字典项
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>设备类型列表</returns>
        Task<List<DictionaryDTO>> FindDeviceTypeItemsAsync(FindDeviceTypeItemsRequest request);
        /// <summary>
        /// 增加分享设备关联用户
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceCodeIsEmpty,UserCodeEmptyError,NoExistDevice,UserNotExistError</errorCodes>
        Task<bool> CreateShareDeviceToUserAsync(CreateShareDeviceToUserRequest request);
        /// <summary>
        /// 删除分享设备关联用户
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceCodeIsEmpty,UserCodeEmptyError,NoExistDevice</errorCodes>
        Task<bool> DeleteShareDeviceToUserAsync(DeleteShareDeviceToUserRequest request);

        /// <summary>
        /// 机构设备移除
        /// </summary>
        /// <param name="request">移除设备请求实体</param>
        /// <returns>是否移除成功：true-成功；false-失败</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceCodeOrOrganizationCodeEmpty,DeviceNotExist</errorCodes>
        Task<bool> RemoveDeviceRelevancyAsync(RemoveDeviceRelevancyRequest request);

        /// <summary>
        /// 查询个人名下所有设备列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns>返回设备信息列表</returns>
        /// <errorCodes>UserNotExistError,OrganizationNotExist</errorCodes>
        Task<PageCollection<DeviceExtendInfoDTO>> GetPersonDeviceListAsync(GetPersonDeviceRequest request);

        /// <summary>
        /// 根据组织编码获取所属全部设备信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DeviceExtendInfoDTO>> FindDevicesByOrganizationCodeAsync(FindDevicesByOrganizationCodeRequest request);

        /// <summary>
        /// 查询个人名下所有设备下拉列表接口
        /// </summary>
        /// <param name="request">签名令牌请求信息</param>
        /// <returns>返回设备下拉信息列表</returns>
        /// <errorCodes>UserNotExistError,OrganizationNotExist</errorCodes>
        Task<List<SelectItemDTO>> GetPersonDeviceDropdownListAsync(TokenRequest request);

        /// <summary>
        /// 查询获取服务器配置信息接口
        /// </summary>
        /// <param name="request">Token验证</param>
        /// <returns>服务器配置信息结果:key:字段，value:数据值，复杂类型可为json</returns>        
        /// <example>设备端API</example>
        /// <errorCodes>NoExistDevice</errorCodes>
        Task<Dictionary<string, string>> QueryServerConfigAsync(TokenRequest request);

        /// <summary>
        /// 添加设备到新的医院请求接口
        /// </summary>
        /// <param name="request">添加设备到新医院中请求实体</param>
        /// <returns>是否成功</returns>
        /// <para>DeviceErrorCodeEnum</para>
        /// <errorCodes>UniqueCodeIsEmpty,NoExistDevice,OrganizationNotExist,UserNotExistError,NotOrgAdmin</errorCodes>
        Task<bool> AddDeviceToOrgAsync(AddDeviceToOrgRequest request);

        /// <summary>
        /// 获取设备绑定用户codes
        /// </summary>
        /// <param name="request">获取设备绑定用户codes请求实体</param>
        /// <returns>"test01","test02"</returns>
        /// <value>"test01","test02"</value>
        /// <errorCodes>DeviceCodeIsEmpty,NoExistDevice</errorCodes>
        Task<List<string>> GetDeviceBindUsersCodesAsync(GetDeviceRequest request);

        /// <summary>
        /// 查询设备AI应用的状态
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>AI应用集合</returns>
        /// <errorCodes>DeviceCodeIsEmpty</errorCodes>
        Task<List<DiagnosisModuleDTO>> FindDeviceDiagnosisModulesAsync(FindDeviceDiagnosisModulesRequest request);

        /// <summary>
        /// 修改设备AI应用启用状态
        /// </summary>
        /// <param name="request">修改设备AI应用启用状态请求实体</param>
        /// <returns>是否成功</returns>
        /// <para>DeviceErrorCodeEnum</para>
        /// <errorCodes>DeviceCodeIsEmpty,DeviceAIDiagnosisModule</errorCodes>
        Task<bool> ModifyDeviceDiagnosisModuleStateAsync(ModifyDeviceDiagnosisModuleStateRequest request);
      

    }
}

==> ReleaseV1.1.3.tar.gz: winginterfacelibrary/src/Interface/IDeviceService.cs <==
﻿using System.Threading.Tasks;
using WingInterfaceLibrary.Request.Device;
using WingInterfaceLibrary.DTO.Device;
using System.Collections.Generic;
using WingInterfaceLibrary.DTO.Dictionary;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.DTO.Management;
using WingInterfaceLibrary.DTO.DiagnosisModule;
using WingInterfaceLibrary.LiveConsultation;
using WingInterfaceLibrary.Result.Languge;
using WingInterfaceLibrary.Request.Examine;
using WingInterfaceLibrary.Request.Remote;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 设备信息服务接口
    /// </summary>
    /// <docFirstDirectory>客户端API</docFirstDirectory>
    /// <docSecondDirectory>设备信息接口</docSecondDirectory>
    public interface IDeviceService
    {
        /// <summary>
        /// 设备心跳
        /// </summary>
        /// <param name="request">设备心跳请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        Task<bool> HeartRateAsync(TokenRequest request);

        Task<DeviceInfoDTO> CreateDeviceInfoAsync(CreateDeviceRequest request);

        /// <summary>
        /// 根据设备code获取设备信息
        /// </summary>
        /// <param name="request">设备code请求实体</param>
        /// <returns>返回查询到的设备对象信息</returns>
        /// <errorCodes>DeviceCodeEmpty,NoExistDevice</errorCodes>
        Task<DeviceExtendInfoDTO> GetDeviceInfoAsync(GetDeviceRequest request);

        /// <summary>
        /// 根据设备动态唯一码获取设备信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        /// <errorCodes>ShortCodeEmpty,NoExistDevice</errorCodes>
        Task<DeviceExtendInfoDTO> GetDeviceByShortCodeAsync(GetDeviceByShortCodeRequest request);

        Task<PageCollection<DeviceInfoDTO>> GetDeviceInfoPageAsync(PageFilterRequest request);

        /// <summary>
        /// 绑定设备
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>UserNotExistError,DeviceNotExist,HasAddedDevice</errorCodes>
        Task<bool> BindDeviceAsync(BindDeviceRequest request);

        /// <summary>
        /// 修改设备信息
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceNotExist,DeviceNameEmpty</errorCodes>
        Task<bool> ModifyDeviceAsync(ModifyDeviceRequest request);

        /// <summary>
        /// 创建设备类型、设备型号字典项
        /// </summary>
        /// <param name="request">请求实体</param>
        /// <returns>字典编码</returns>
        /// <value>DictionaryDO_2022030202525405wUxJ</value>
        Task<string> CreateDictionaryItemAsync(CreateDictionaryItemRequest request);

        /// <summary>
        /// 查找设备型号所有字典项
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>设备型号列表</returns>
        Task<List<DictionaryDTO>> FindDeviceModelItemsAsync(FindDeviceModelItemsRequest request);

        /// <summary>
        /// 查找设备类型所有字典项
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>设备类型列表</returns>
        Task<List<DictionaryDTO>> FindDeviceTypeItemsAsync(FindDeviceTypeItemsRequest request);
        /// <summary>
        /// 增加分享设备关联用户
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceCodeIsEmpty,UserCodeEmptyError,NoExistDevice,UserNotExistError</errorCodes>
        Task<bool> CreateShareDeviceToUserAsync(CreateShareDeviceToUserRequest request);
        /// <summary>
        /// 删除分享设备关联用户
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceCodeIsEmpty,UserCodeEmptyError,NoExistDevice</errorCodes>
        Task<bool> DeleteShareDeviceToUserAsync(DeleteShareDeviceToUserRequest request);

        /// <summary>
        /// 机构设备移除
        /// </summary>
        /// <param name="request">移除设备请求实体</param>
        /// <returns>是否移除成功：true-成功；false-失败</returns>
        /// <value>true</value>
        /// <errorCodes>DeviceCodeOrOrganizationCodeEmpty,DeviceNotExist</errorCodes>
        Task<bool> RemoveDeviceRelevancyAsync(RemoveDeviceRelevancyRequest request);

        /// <summary>
        /// 查询个人名下所有设备列表接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns>返回设备信息列表</returns>
        /// <errorCodes>UserNotExistError,OrganizationNotExist</errorCodes>
        Task<PageCollection<DeviceExtendInfoDTO>> GetPersonDeviceListAsync(GetPersonDeviceRequest request);

        /// <summary>
        /// 根据组织编码获取所属全部设备信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<List<DeviceExtendInfoDTO>> FindDevicesByOrganizationCodeAsync(FindDevicesByOrganizationCodeRequest request);

        /// <summary>
        /// 查询个人名下所有设备下拉列表接口
        /// </summary>
        /// <param name="request">签名令牌请求信息</param>
        /// <returns>返回设备下拉信息列表</returns>
        /// <errorCodes>UserNotExistError,OrganizationNotExist</errorCodes>
        Task<List<SelectItemDTO>> GetPersonDeviceDropdownListAsync(TokenRequest request);

        /// <summary>
        /// 查询获取服务器配置信息接口
        /// </summary>
        /// <param name="request">Token验证</param>
        /// <returns>服务器配置信息结果:key:字段，value:数据值，复杂类型可为json</returns>        
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>设备信息接口</docSecondDirectory>
        /// <errorCodes>NoExistDevice</errorCodes>
        Task<DeviceServerSettingResult> QueryServerConfigAsync(TokenRequest request);

        /// <summary>
        /// 添加设备到新的医院请求接口
        /// </summary>
        /// <param name="request">添加设备到新医院中请求实体</param>
        /// <returns>是否成功</returns>
        /// <errorCodes>UniqueCodeIsEmpty,NoExistDevice,OrganizationNotExist,UserNotExistError,NotOrgAdmin</errorCodes>
        Task<bool> AddDeviceToOrgAsync(AddDeviceToOrgRequest request);

        /// <summary>
        /// 获取设备绑定用户codes
        /// </summary>
        /// <param name="request">获取设备绑定用户codes请求实体</param>
        /// <returns>"test01","test02"</returns>
        /// <value>"test01","test02"</value>
        /// <errorCodes>DeviceCodeIsEmpty,NoExistDevice</errorCodes>
        Task<List<string>> GetDeviceBindUsersCodesAsync(GetDeviceRequest request);

        /// <summary>
        /// 查询设备AI应用的状态
        /// </summary>
        /// <param name="request">请求参数</param>
        /// <returns>AI应用集合</returns>
        /// <errorCodes>DeviceCodeIsEmpty</errorCodes>
        Task<List<DiagnosisModuleDTO>> FindDeviceDiagnosisModulesAsync(FindDeviceDiagnosisModulesRequest request);

        /// <summary>
        /// 修改设备AI应用启用状态
        /// </summary>
        /// <param name="request">修改设备AI应用启用状态请求实体</param>
        /// <returns>是否成功</returns>
        /// <errorCodes>DeviceCodeIsEmpty,DeviceAIDiagnosisModule</errorCodes>
        Task<bool> ModifyDeviceDiagnosisModuleStateAsync(ModifyDeviceDiagnosisModuleStateRequest request);

        /// <summary>
        /// 上报设备画面尺寸相关信息
        /// </summary>
        /// <param name="request"></param>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>实时会诊服务接口</docSecondDirectory>   
        /// <docThirdDirectory>会诊</docThirdDirectory>  
        /// <returns></returns>
        Task<ReportVideoDeviceInfoResult> ReportVideoDeviceInfoAsync(ReportVideoDeviceInfoRequest request);

        /// <summary>
        /// 查找有效设备总数量
        /// </summary>
        /// <returns></returns>
        Task<long> GetActiveDeviceCount();

        /// <summary>
        /// 设备发送调参数据
        /// </summary>
        /// <param name="request">调参数据请求</param>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>实时会诊服务接口</docSecondDirectory>   
        /// <docThirdDirectory>会诊</docThirdDirectory>  
        /// <returns></returns>
        Task<bool> SendControlParameterByDeviceAsync(SendControlParameterByDeviceRequest request);

        /// <summary>
        /// 用户进入设备直播房间
        /// </summary>
        /// <param name="request">用户进入设备直播房间请求实体</param>
        /// <errorCodes></errorCodes>
        /// <returns></returns>
        Task<JoinDeviceLiveRoomResult> JoinDeviceLiveRoomAsync(JoinDeviceLiveRoomRequest request);

        /// <summary>
        /// 用户离开设备直播房间
        /// </summary>
        /// <param name="request">用户离开设备直播房间请求实体</param>
        /// <errorCodes></errorCodes>
        /// <returns></returns>
        Task<bool> LeaveDeviceLiveRoomAsync(LeaveDeviceLiveRoomRequest request);

        /// <summary>
        /// 上报观看直播状态
        /// </summary>
        /// <param name="request">上报观看直播状态请求实体</param>
        /// <errorCodes></errorCodes>
        /// <returns></returns>
        Task<bool> ReportLiveViewStateAsync(ReportLiveViewStateRequest request);

        /// <summary>
        /// 上报直播状态
        /// </summary>
        /// <param name="request">上报直播状态请求实体</param>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>设备信息接口</docSecondDirectory>  
        /// <errorCodes></errorCodes>
        /// <returns></returns>
        Task<bool> ReportLiveStateAsync(ReportLiveStateRequest request);

        /// <summary>
        /// 获取实时音视频参数
        /// </summary>
        /// <param name="request">获取实时音视频参数请求实体</param>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>设备信息接口</docSecondDirectory>  
        /// <errorCodes></errorCodes>
        /// <returns></returns>
        Task<CreateLiveRoomInfoResult> CreateLiveRoomInfoAsync(CreateLiveRoomInfoRequest request);

        /// <summary>
        /// 拒绝远程控制
        /// </summary>
        /// <param name="request"></param>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>远程控制接口</docSecondDirectory>  
        /// <returns></returns>
        Task<bool> RejectRemoteControl(RemoteControlRequest request);

        /// <summary>
        /// 断开远程控制
        /// </summary>
        /// <param name="request"></param>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>远程控制接口</docSecondDirectory>  
        /// <returns></returns>
        Task<bool> DisconnectRemoteControl(RemoteControlRequest request);

        /// <summary>
        /// 上传会诊图像
        /// </summary>
        /// <param name="request">上传会诊图像请求实体</param>
        /// <returns>上传会诊图像结果</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        /// <docFirstDirectory>设备端API</docFirstDirectory>
        /// <docSecondDirectory>实时会诊服务接口</docSecondDirectory>
        /// <errorCodes>ConsultationCodeIsEmpty,FileTokenIsEmpty,ConsultationNotExisted</errorCodes>
        Task<bool> UploadConsultationDataAsync(UploadConsultationDataRequest request);//todo 错误码
       
        /// <summary>
        /// 获取设备参数调节数据请求
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<DeviceControlParameterDataDTO> GetControlParametersAsync(GetControlParametersRequest request);

        #region Remote Maintain
        /// <summary>
        /// 申请连接/断开请求接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ApplyRemoteConnectionAsync(ControlDeviceConnectRequest request);

        /// <summary>
        /// 设备端接受连接/断开链接请求接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AcceptRemoteConnnectionAsync(ControlDeviceResponseRequest request);

        /// <summary>
        /// 远程控制请求接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ApplyRemoteControlAsync(ControlDeviceParameterRequest request);

        /// <summary>
        /// 获取日志请求接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> GetRemoteLogAsync(GetRemoteLogRequest request);

        /// <summary>
        /// 设备端响应日志下载地址请求接口
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> ResponseRemoteLogAsync(RemoteLogResponseRequest request);
        #endregion 
    }
}
